/*
 * GtkCalendar.java
 *
 * Copyright (c) 2006-2009 Operational Dynamics Consulting Pty Ltd, and Others
 *
 * The code in this file, and the program it is a part of, are made available
 * to you by the authors under the terms of the "GNU General Public Licence,
 * version 2" plus the "Classpath Exception" (you may link to this code as a
 * library into other programs provided you don't make a derivation of it).
 * See the LICENCE file for the terms governing usage and redistribution.
 *
 *                      THIS FILE IS GENERATED CODE!
 *
 * To modify its contents or behaviour, either update the generation program,
 * change the information in the source defs file, or implement an override for
 * this class.
 */
package org.gnome.gtk;

import org.gnome.glib.Signal;
import org.gnome.gtk.Calendar;
import org.gnome.gtk.CalendarDisplayOptions;
import org.gnome.gtk.Plumbing;

final class GtkCalendar extends Plumbing
{
    private GtkCalendar() {}

    static final long createCalendar() {
        long result;

        synchronized (lock) {
            result = gtk_calendar_new();

            return result;
        }
    }

    private static native final long gtk_calendar_new();

    static final boolean selectMonth(Calendar self, int month, int year) {
        boolean result;

        if (self == null) {
            throw new IllegalArgumentException("self can't be null");
        }

        synchronized (lock) {
            result = gtk_calendar_select_month(pointerOf(self), month, year);

            return result;
        }
    }

    private static native final boolean gtk_calendar_select_month(long self, int month, int year);

    static final void selectDay(Calendar self, int day) {
        if (self == null) {
            throw new IllegalArgumentException("self can't be null");
        }

        synchronized (lock) {
            gtk_calendar_select_day(pointerOf(self), day);
        }
    }

    private static native final void gtk_calendar_select_day(long self, int day);

    static final boolean markDay(Calendar self, int day) {
        boolean result;

        if (self == null) {
            throw new IllegalArgumentException("self can't be null");
        }

        synchronized (lock) {
            result = gtk_calendar_mark_day(pointerOf(self), day);

            return result;
        }
    }

    private static native final boolean gtk_calendar_mark_day(long self, int day);

    static final boolean unmarkDay(Calendar self, int day) {
        boolean result;

        if (self == null) {
            throw new IllegalArgumentException("self can't be null");
        }

        synchronized (lock) {
            result = gtk_calendar_unmark_day(pointerOf(self), day);

            return result;
        }
    }

    private static native final boolean gtk_calendar_unmark_day(long self, int day);

    static final void clearMarks(Calendar self) {
        if (self == null) {
            throw new IllegalArgumentException("self can't be null");
        }

        synchronized (lock) {
            gtk_calendar_clear_marks(pointerOf(self));
        }
    }

    private static native final void gtk_calendar_clear_marks(long self);

    static final void setDisplayOptions(Calendar self, CalendarDisplayOptions flags) {
        if (self == null) {
            throw new IllegalArgumentException("self can't be null");
        }

        if (flags == null) {
            throw new IllegalArgumentException("flags can't be null");
        }

        synchronized (lock) {
            gtk_calendar_set_display_options(pointerOf(self), numOf(flags));
        }
    }

    private static native final void gtk_calendar_set_display_options(long self, int flags);

    static final CalendarDisplayOptions getDisplayOptions(Calendar self) {
        int result;

        if (self == null) {
            throw new IllegalArgumentException("self can't be null");
        }

        synchronized (lock) {
            result = gtk_calendar_get_display_options(pointerOf(self));

            return (CalendarDisplayOptions) flagFor(CalendarDisplayOptions.class, result);
        }
    }

    private static native final int gtk_calendar_get_display_options(long self);

    static final void getDate(Calendar self, int[] year, int[] month, int[] day) {
        if (self == null) {
            throw new IllegalArgumentException("self can't be null");
        }

        synchronized (lock) {
            gtk_calendar_get_date(pointerOf(self), year, month, day);
        }
    }

    private static native final void gtk_calendar_get_date(long self, int[] year, int[] month, int[] day);

    interface MonthChangedSignal extends Signal
    {
        void onMonthChanged(Calendar source);
    }

    static final void connect(Calendar self, GtkCalendar.MonthChangedSignal handlerInstance, boolean after) {
        connectSignal(self, handlerInstance, GtkCalendar.class, "month-changed", after);
    }

    protected static final void receiveMonthChanged(Signal handler, long source) {
        ((GtkCalendar.MonthChangedSignal) handler).onMonthChanged((Calendar) objectFor(source));
    }

    interface DaySelectedSignal extends Signal
    {
        void onDaySelected(Calendar source);
    }

    static final void connect(Calendar self, GtkCalendar.DaySelectedSignal handlerInstance, boolean after) {
        connectSignal(self, handlerInstance, GtkCalendar.class, "day-selected", after);
    }

    protected static final void receiveDaySelected(Signal handler, long source) {
        ((GtkCalendar.DaySelectedSignal) handler).onDaySelected((Calendar) objectFor(source));
    }

    interface DaySelectedDoubleClickSignal extends Signal
    {
        void onDaySelectedDoubleClick(Calendar source);
    }

    static final void connect(Calendar self, GtkCalendar.DaySelectedDoubleClickSignal handlerInstance, boolean after) {
        connectSignal(self, handlerInstance, GtkCalendar.class, "day-selected-double-click", after);
    }

    protected static final void receiveDaySelectedDoubleClick(Signal handler, long source) {
        ((GtkCalendar.DaySelectedDoubleClickSignal) handler).onDaySelectedDoubleClick((Calendar) objectFor(source));
    }

    interface PrevMonthSignal extends Signal
    {
        void onPrevMonth(Calendar source);
    }

    static final void connect(Calendar self, GtkCalendar.PrevMonthSignal handlerInstance, boolean after) {
        connectSignal(self, handlerInstance, GtkCalendar.class, "prev-month", after);
    }

    protected static final void receivePrevMonth(Signal handler, long source) {
        ((GtkCalendar.PrevMonthSignal) handler).onPrevMonth((Calendar) objectFor(source));
    }

    interface NextMonthSignal extends Signal
    {
        void onNextMonth(Calendar source);
    }

    static final void connect(Calendar self, GtkCalendar.NextMonthSignal handlerInstance, boolean after) {
        connectSignal(self, handlerInstance, GtkCalendar.class, "next-month", after);
    }

    protected static final void receiveNextMonth(Signal handler, long source) {
        ((GtkCalendar.NextMonthSignal) handler).onNextMonth((Calendar) objectFor(source));
    }

    interface PrevYearSignal extends Signal
    {
        void onPrevYear(Calendar source);
    }

    static final void connect(Calendar self, GtkCalendar.PrevYearSignal handlerInstance, boolean after) {
        connectSignal(self, handlerInstance, GtkCalendar.class, "prev-year", after);
    }

    protected static final void receivePrevYear(Signal handler, long source) {
        ((GtkCalendar.PrevYearSignal) handler).onPrevYear((Calendar) objectFor(source));
    }

    interface NextYearSignal extends Signal
    {
        void onNextYear(Calendar source);
    }

    static final void connect(Calendar self, GtkCalendar.NextYearSignal handlerInstance, boolean after) {
        connectSignal(self, handlerInstance, GtkCalendar.class, "next-year", after);
    }

    protected static final void receiveNextYear(Signal handler, long source) {
        ((GtkCalendar.NextYearSignal) handler).onNextYear((Calendar) objectFor(source));
    }
}

