/*
 * GtkIMContext.java
 *
 * Copyright (c) 2006-2009 Operational Dynamics Consulting Pty Ltd, and Others
 *
 * The code in this file, and the program it is a part of, are made available
 * to you by the authors under the terms of the "GNU General Public Licence,
 * version 2" plus the "Classpath Exception" (you may link to this code as a
 * library into other programs provided you don't make a derivation of it).
 * See the LICENCE file for the terms governing usage and redistribution.
 *
 *                      THIS FILE IS GENERATED CODE!
 *
 * To modify its contents or behaviour, either update the generation program,
 * change the information in the source defs file, or implement an override for
 * this class.
 */
package org.gnome.gtk;

import org.gnome.gdk.EventKey;
import org.gnome.gdk.Rectangle;
import org.gnome.gdk.Window;
import org.gnome.glib.Signal;
import org.gnome.gtk.IMContext;
import org.gnome.gtk.Plumbing;
import org.gnome.pango.AttributeList;

final class GtkIMContext extends Plumbing
{
    private GtkIMContext() {}

    static final void setClientWindow(IMContext self, Window window) {
        if (self == null) {
            throw new IllegalArgumentException("self can't be null");
        }

        if (window == null) {
            throw new IllegalArgumentException("window can't be null");
        }

        synchronized (lock) {
            gtk_im_context_set_client_window(pointerOf(self), pointerOf(window));
        }
    }

    private static native final void gtk_im_context_set_client_window(long self, long window);

    static final void getPreeditString(IMContext self, String[] str, AttributeList[] attrs, int[] cursorPos) {
        long[] _attrs;

        if (self == null) {
            throw new IllegalArgumentException("self can't be null");
        }

        if (str == null) {
            throw new IllegalArgumentException("str can't be null");
        }

        if (attrs == null) {
            throw new IllegalArgumentException("attrs can't be null");
        }

        if (cursorPos == null) {
            throw new IllegalArgumentException("cursorPos can't be null");
        }

        _attrs = pointersOf(attrs);

        synchronized (lock) {
            gtk_im_context_get_preedit_string(pointerOf(self), str, _attrs, cursorPos);
            fillBoxedArray(AttributeList.class, attrs, _attrs);
        }
    }

    private static native final void gtk_im_context_get_preedit_string(long self, String[] str, long[] attrs, int[] cursorPos);

    static final boolean filterKeypress(IMContext self, EventKey event) {
        boolean result;

        if (self == null) {
            throw new IllegalArgumentException("self can't be null");
        }

        if (event == null) {
            throw new IllegalArgumentException("event can't be null");
        }

        synchronized (lock) {
            result = gtk_im_context_filter_keypress(pointerOf(self), pointerOf(event));

            return result;
        }
    }

    private static native final boolean gtk_im_context_filter_keypress(long self, long event);

    static final void focusIn(IMContext self) {
        if (self == null) {
            throw new IllegalArgumentException("self can't be null");
        }

        synchronized (lock) {
            gtk_im_context_focus_in(pointerOf(self));
        }
    }

    private static native final void gtk_im_context_focus_in(long self);

    static final void focusOut(IMContext self) {
        if (self == null) {
            throw new IllegalArgumentException("self can't be null");
        }

        synchronized (lock) {
            gtk_im_context_focus_out(pointerOf(self));
        }
    }

    private static native final void gtk_im_context_focus_out(long self);

    static final void reset(IMContext self) {
        if (self == null) {
            throw new IllegalArgumentException("self can't be null");
        }

        synchronized (lock) {
            gtk_im_context_reset(pointerOf(self));
        }
    }

    private static native final void gtk_im_context_reset(long self);

    static final void setCursorLocation(IMContext self, Rectangle area) {
        if (self == null) {
            throw new IllegalArgumentException("self can't be null");
        }

        if (area == null) {
            throw new IllegalArgumentException("area can't be null");
        }

        synchronized (lock) {
            gtk_im_context_set_cursor_location(pointerOf(self), pointerOf(area));
        }
    }

    private static native final void gtk_im_context_set_cursor_location(long self, long area);

    static final void setUsePreedit(IMContext self, boolean usePreedit) {
        if (self == null) {
            throw new IllegalArgumentException("self can't be null");
        }

        synchronized (lock) {
            gtk_im_context_set_use_preedit(pointerOf(self), usePreedit);
        }
    }

    private static native final void gtk_im_context_set_use_preedit(long self, boolean usePreedit);

    static final void setSurrounding(IMContext self, String text, int len, int cursorIndex) {
        if (self == null) {
            throw new IllegalArgumentException("self can't be null");
        }

        if (text == null) {
            throw new IllegalArgumentException("text can't be null");
        }

        synchronized (lock) {
            gtk_im_context_set_surrounding(pointerOf(self), text, len, cursorIndex);
        }
    }

    private static native final void gtk_im_context_set_surrounding(long self, String text, int len, int cursorIndex);

    static final boolean getSurrounding(IMContext self, String[] text, int[] cursorIndex) {
        boolean result;

        if (self == null) {
            throw new IllegalArgumentException("self can't be null");
        }

        if (text == null) {
            throw new IllegalArgumentException("text can't be null");
        }

        if (cursorIndex == null) {
            throw new IllegalArgumentException("cursorIndex can't be null");
        }

        synchronized (lock) {
            result = gtk_im_context_get_surrounding(pointerOf(self), text, cursorIndex);

            return result;
        }
    }

    private static native final boolean gtk_im_context_get_surrounding(long self, String[] text, int[] cursorIndex);

    static final boolean deleteSurrounding(IMContext self, int offset, int nChars) {
        boolean result;

        if (self == null) {
            throw new IllegalArgumentException("self can't be null");
        }

        synchronized (lock) {
            result = gtk_im_context_delete_surrounding(pointerOf(self), offset, nChars);

            return result;
        }
    }

    private static native final boolean gtk_im_context_delete_surrounding(long self, int offset, int nChars);

    interface PreeditStartSignal extends Signal
    {
        void onPreeditStart(IMContext source);
    }

    static final void connect(IMContext self, GtkIMContext.PreeditStartSignal handlerInstance, boolean after) {
        connectSignal(self, handlerInstance, GtkIMContext.class, "preedit-start", after);
    }

    protected static final void receivePreeditStart(Signal handler, long source) {
        ((GtkIMContext.PreeditStartSignal) handler).onPreeditStart((IMContext) objectFor(source));
    }

    interface PreeditEndSignal extends Signal
    {
        void onPreeditEnd(IMContext source);
    }

    static final void connect(IMContext self, GtkIMContext.PreeditEndSignal handlerInstance, boolean after) {
        connectSignal(self, handlerInstance, GtkIMContext.class, "preedit-end", after);
    }

    protected static final void receivePreeditEnd(Signal handler, long source) {
        ((GtkIMContext.PreeditEndSignal) handler).onPreeditEnd((IMContext) objectFor(source));
    }

    interface PreeditChangedSignal extends Signal
    {
        void onPreeditChanged(IMContext source);
    }

    static final void connect(IMContext self, GtkIMContext.PreeditChangedSignal handlerInstance, boolean after) {
        connectSignal(self, handlerInstance, GtkIMContext.class, "preedit-changed", after);
    }

    protected static final void receivePreeditChanged(Signal handler, long source) {
        ((GtkIMContext.PreeditChangedSignal) handler).onPreeditChanged((IMContext) objectFor(source));
    }

    interface CommitSignal extends Signal
    {
        void onCommit(IMContext source, String str);
    }

    static final void connect(IMContext self, GtkIMContext.CommitSignal handlerInstance, boolean after) {
        connectSignal(self, handlerInstance, GtkIMContext.class, "commit", after);
    }

    protected static final void receiveCommit(Signal handler, long source, String str) {
        ((GtkIMContext.CommitSignal) handler).onCommit((IMContext) objectFor(source), str);
    }

    interface RetrieveSurroundingSignal extends Signal
    {
        boolean onRetrieveSurrounding(IMContext source);
    }

    static final void connect(IMContext self, GtkIMContext.RetrieveSurroundingSignal handlerInstance, boolean after) {
        connectSignal(self, handlerInstance, GtkIMContext.class, "retrieve-surrounding", after);
    }

    protected static final boolean receiveRetrieveSurrounding(Signal handler, long source) {
        boolean result;

        result = ((GtkIMContext.RetrieveSurroundingSignal) handler).onRetrieveSurrounding((IMContext) objectFor(source));

        return result;
    }

    interface DeleteSurroundingSignal extends Signal
    {
        boolean onDeleteSurrounding(IMContext source, int offset, int nChars);
    }

    static final void connect(IMContext self, GtkIMContext.DeleteSurroundingSignal handlerInstance, boolean after) {
        connectSignal(self, handlerInstance, GtkIMContext.class, "delete-surrounding", after);
    }

    protected static final boolean receiveDeleteSurrounding(Signal handler, long source, int offset, int nChars) {
        boolean result;

        result = ((GtkIMContext.DeleteSurroundingSignal) handler).onDeleteSurrounding((IMContext) objectFor(source), offset, nChars);

        return result;
    }

    interface SetClientWindowSignal extends Signal
    {
        void onSetClientWindow(IMContext source, Window window);
    }

    static final void connect(IMContext self, GtkIMContext.SetClientWindowSignal handlerInstance, boolean after) {
        connectSignal(self, handlerInstance, GtkIMContext.class, "set-client-window", after);
    }

    protected static final void receiveSetClientWindow(Signal handler, long source, long window) {
        ((GtkIMContext.SetClientWindowSignal) handler).onSetClientWindow((IMContext) objectFor(source), (Window) objectFor(window));
    }

    interface GetPreeditStringSignal extends Signal
    {
        void onGetPreeditString(IMContext source, String[] str, AttributeList[] attrs, int[] cursorPos);
    }

    static final void connect(IMContext self, GtkIMContext.GetPreeditStringSignal handlerInstance, boolean after) {
        connectSignal(self, handlerInstance, GtkIMContext.class, "get-preedit-string", after);
    }

    protected static final void receiveGetPreeditString(Signal handler, long source, String[] str, long[] attrs, int[] cursorPos) {
        ((GtkIMContext.GetPreeditStringSignal) handler).onGetPreeditString((IMContext) objectFor(source), str, (AttributeList[]) boxedArrayFor(AttributeList.class, attrs, new AttributeList[attrs.length]), cursorPos);
    }

    interface FilterKeypressSignal extends Signal
    {
        boolean onFilterKeypress(IMContext source, EventKey event);
    }

    static final void connect(IMContext self, GtkIMContext.FilterKeypressSignal handlerInstance, boolean after) {
        connectSignal(self, handlerInstance, GtkIMContext.class, "filter-keypress", after);
    }

    protected static final boolean receiveFilterKeypress(Signal handler, long source, long event) {
        boolean result;

        result = ((GtkIMContext.FilterKeypressSignal) handler).onFilterKeypress((IMContext) objectFor(source), (EventKey) boxedFor(EventKey.class, event));

        return result;
    }

    interface FocusInSignal extends Signal
    {
        void onFocusIn(IMContext source);
    }

    static final void connect(IMContext self, GtkIMContext.FocusInSignal handlerInstance, boolean after) {
        connectSignal(self, handlerInstance, GtkIMContext.class, "focus-in", after);
    }

    protected static final void receiveFocusIn(Signal handler, long source) {
        ((GtkIMContext.FocusInSignal) handler).onFocusIn((IMContext) objectFor(source));
    }

    interface FocusOutSignal extends Signal
    {
        void onFocusOut(IMContext source);
    }

    static final void connect(IMContext self, GtkIMContext.FocusOutSignal handlerInstance, boolean after) {
        connectSignal(self, handlerInstance, GtkIMContext.class, "focus-out", after);
    }

    protected static final void receiveFocusOut(Signal handler, long source) {
        ((GtkIMContext.FocusOutSignal) handler).onFocusOut((IMContext) objectFor(source));
    }

    interface ResetSignal extends Signal
    {
        void onReset(IMContext source);
    }

    static final void connect(IMContext self, GtkIMContext.ResetSignal handlerInstance, boolean after) {
        connectSignal(self, handlerInstance, GtkIMContext.class, "reset", after);
    }

    protected static final void receiveReset(Signal handler, long source) {
        ((GtkIMContext.ResetSignal) handler).onReset((IMContext) objectFor(source));
    }

    interface SetCursorLocationSignal extends Signal
    {
        void onSetCursorLocation(IMContext source, Rectangle area);
    }

    static final void connect(IMContext self, GtkIMContext.SetCursorLocationSignal handlerInstance, boolean after) {
        connectSignal(self, handlerInstance, GtkIMContext.class, "set-cursor-location", after);
    }

    protected static final void receiveSetCursorLocation(Signal handler, long source, long area) {
        ((GtkIMContext.SetCursorLocationSignal) handler).onSetCursorLocation((IMContext) objectFor(source), (Rectangle) boxedFor(Rectangle.class, area));
    }

    interface SetUsePreeditSignal extends Signal
    {
        void onSetUsePreedit(IMContext source, boolean usePreedit);
    }

    static final void connect(IMContext self, GtkIMContext.SetUsePreeditSignal handlerInstance, boolean after) {
        connectSignal(self, handlerInstance, GtkIMContext.class, "set-use-preedit", after);
    }

    protected static final void receiveSetUsePreedit(Signal handler, long source, boolean usePreedit) {
        ((GtkIMContext.SetUsePreeditSignal) handler).onSetUsePreedit((IMContext) objectFor(source), usePreedit);
    }

    interface SetSurroundingSignal extends Signal
    {
        void onSetSurrounding(IMContext source, String text, int len, int cursorIndex);
    }

    static final void connect(IMContext self, GtkIMContext.SetSurroundingSignal handlerInstance, boolean after) {
        connectSignal(self, handlerInstance, GtkIMContext.class, "set-surrounding", after);
    }

    protected static final void receiveSetSurrounding(Signal handler, long source, String text, int len, int cursorIndex) {
        ((GtkIMContext.SetSurroundingSignal) handler).onSetSurrounding((IMContext) objectFor(source), text, len, cursorIndex);
    }

    interface GetSurroundingSignal extends Signal
    {
        boolean onGetSurrounding(IMContext source, String[] text, int[] cursorIndex);
    }

    static final void connect(IMContext self, GtkIMContext.GetSurroundingSignal handlerInstance, boolean after) {
        connectSignal(self, handlerInstance, GtkIMContext.class, "get-surrounding", after);
    }

    protected static final boolean receiveGetSurrounding(Signal handler, long source, String[] text, int[] cursorIndex) {
        boolean result;

        result = ((GtkIMContext.GetSurroundingSignal) handler).onGetSurrounding((IMContext) objectFor(source), text, cursorIndex);

        return result;
    }
}

