/*
 * GtkMenuItem.java
 *
 * Copyright (c) 2006-2009 Operational Dynamics Consulting Pty Ltd, and Others
 *
 * The code in this file, and the program it is a part of, are made available
 * to you by the authors under the terms of the "GNU General Public Licence,
 * version 2" plus the "Classpath Exception" (you may link to this code as a
 * library into other programs provided you don't make a derivation of it).
 * See the LICENCE file for the terms governing usage and redistribution.
 *
 *                      THIS FILE IS GENERATED CODE!
 *
 * To modify its contents or behaviour, either update the generation program,
 * change the information in the source defs file, or implement an override for
 * this class.
 */
package org.gnome.gtk;

import org.gnome.glib.Signal;
import org.gnome.gtk.MenuItem;
import org.gnome.gtk.Plumbing;
import org.gnome.gtk.Widget;

final class GtkMenuItem extends Plumbing
{
    private GtkMenuItem() {}

    static final long createMenuItem() {
        long result;

        synchronized (lock) {
            result = gtk_menu_item_new();

            return result;
        }
    }

    private static native final long gtk_menu_item_new();

    static final long createMenuItemWithLabel(String label) {
        long result;

        if (label == null) {
            throw new IllegalArgumentException("label can't be null");
        }

        synchronized (lock) {
            result = gtk_menu_item_new_with_label(label);

            return result;
        }
    }

    private static native final long gtk_menu_item_new_with_label(String label);

    static final long createMenuItemWithMnemonic(String label) {
        long result;

        if (label == null) {
            throw new IllegalArgumentException("label can't be null");
        }

        synchronized (lock) {
            result = gtk_menu_item_new_with_mnemonic(label);

            return result;
        }
    }

    private static native final long gtk_menu_item_new_with_mnemonic(String label);

    static final void setSubmenu(MenuItem self, Widget submenu) {
        if (self == null) {
            throw new IllegalArgumentException("self can't be null");
        }

        if (submenu == null) {
            throw new IllegalArgumentException("submenu can't be null");
        }

        synchronized (lock) {
            gtk_menu_item_set_submenu(pointerOf(self), pointerOf(submenu));
        }
    }

    private static native final void gtk_menu_item_set_submenu(long self, long submenu);

    static final Widget getSubmenu(MenuItem self) {
        long result;

        if (self == null) {
            throw new IllegalArgumentException("self can't be null");
        }

        synchronized (lock) {
            result = gtk_menu_item_get_submenu(pointerOf(self));

            return (Widget) objectFor(result);
        }
    }

    private static native final long gtk_menu_item_get_submenu(long self);

    static final void select(MenuItem self) {
        if (self == null) {
            throw new IllegalArgumentException("self can't be null");
        }

        synchronized (lock) {
            gtk_menu_item_select(pointerOf(self));
        }
    }

    private static native final void gtk_menu_item_select(long self);

    static final void deselect(MenuItem self) {
        if (self == null) {
            throw new IllegalArgumentException("self can't be null");
        }

        synchronized (lock) {
            gtk_menu_item_deselect(pointerOf(self));
        }
    }

    private static native final void gtk_menu_item_deselect(long self);

    static final void activate(MenuItem self) {
        if (self == null) {
            throw new IllegalArgumentException("self can't be null");
        }

        synchronized (lock) {
            gtk_menu_item_activate(pointerOf(self));
        }
    }

    private static native final void gtk_menu_item_activate(long self);

    static final void toggleSizeRequest(MenuItem self, int[] requisition) {
        if (self == null) {
            throw new IllegalArgumentException("self can't be null");
        }

        if (requisition == null) {
            throw new IllegalArgumentException("requisition can't be null");
        }

        synchronized (lock) {
            gtk_menu_item_toggle_size_request(pointerOf(self), requisition);
        }
    }

    private static native final void gtk_menu_item_toggle_size_request(long self, int[] requisition);

    static final void toggleSizeAllocate(MenuItem self, int allocation) {
        if (self == null) {
            throw new IllegalArgumentException("self can't be null");
        }

        synchronized (lock) {
            gtk_menu_item_toggle_size_allocate(pointerOf(self), allocation);
        }
    }

    private static native final void gtk_menu_item_toggle_size_allocate(long self, int allocation);

    static final void setRightJustified(MenuItem self, boolean rightJustified) {
        if (self == null) {
            throw new IllegalArgumentException("self can't be null");
        }

        synchronized (lock) {
            gtk_menu_item_set_right_justified(pointerOf(self), rightJustified);
        }
    }

    private static native final void gtk_menu_item_set_right_justified(long self, boolean rightJustified);

    static final boolean getRightJustified(MenuItem self) {
        boolean result;

        if (self == null) {
            throw new IllegalArgumentException("self can't be null");
        }

        synchronized (lock) {
            result = gtk_menu_item_get_right_justified(pointerOf(self));

            return result;
        }
    }

    private static native final boolean gtk_menu_item_get_right_justified(long self);

    static final void setAccelPath(MenuItem self, String accelPath) {
        if (self == null) {
            throw new IllegalArgumentException("self can't be null");
        }

        synchronized (lock) {
            gtk_menu_item_set_accel_path(pointerOf(self), accelPath);
        }
    }

    private static native final void gtk_menu_item_set_accel_path(long self, String accelPath);

    interface ActivateSignal extends Signal
    {
        void onActivate(MenuItem source);
    }

    static final void connect(MenuItem self, GtkMenuItem.ActivateSignal handlerInstance, boolean after) {
        connectSignal(self, handlerInstance, GtkMenuItem.class, "activate", after);
    }

    protected static final void receiveActivate(Signal handler, long source) {
        ((GtkMenuItem.ActivateSignal) handler).onActivate((MenuItem) objectFor(source));
    }

    interface ActivateItemSignal extends Signal
    {
        void onActivateItem(MenuItem source);
    }

    static final void connect(MenuItem self, GtkMenuItem.ActivateItemSignal handlerInstance, boolean after) {
        connectSignal(self, handlerInstance, GtkMenuItem.class, "activate-item", after);
    }

    protected static final void receiveActivateItem(Signal handler, long source) {
        ((GtkMenuItem.ActivateItemSignal) handler).onActivateItem((MenuItem) objectFor(source));
    }

    interface ToggleSizeRequestSignal extends Signal
    {
        void onToggleSizeRequest(MenuItem source, int[] requisition);
    }

    static final void connect(MenuItem self, GtkMenuItem.ToggleSizeRequestSignal handlerInstance, boolean after) {
        connectSignal(self, handlerInstance, GtkMenuItem.class, "toggle-size-request", after);
    }

    protected static final void receiveToggleSizeRequest(Signal handler, long source, int[] requisition) {
        ((GtkMenuItem.ToggleSizeRequestSignal) handler).onToggleSizeRequest((MenuItem) objectFor(source), requisition);
    }

    interface ToggleSizeAllocateSignal extends Signal
    {
        void onToggleSizeAllocate(MenuItem source, int allocation);
    }

    static final void connect(MenuItem self, GtkMenuItem.ToggleSizeAllocateSignal handlerInstance, boolean after) {
        connectSignal(self, handlerInstance, GtkMenuItem.class, "toggle-size-allocate", after);
    }

    protected static final void receiveToggleSizeAllocate(Signal handler, long source, int allocation) {
        ((GtkMenuItem.ToggleSizeAllocateSignal) handler).onToggleSizeAllocate((MenuItem) objectFor(source), allocation);
    }
}

